This package is intended to be used for interpreting connectomics data. 

To install: 
```
pip install connectome-interpreter
```

Documentation [here](https://connectome-interpreter.readthedocs.io/en/latest/). 

See [this colab notebook](https://colab.research.google.com/drive/1VIMNFBp7dCgN5XOQ9vvzPaqb80BGPZx4?usp=sharing) for example analysis using the larval connectome from [Winding et al. 2023](https://www.science.org/doi/10.1126/science.add9330). 
